#include "config.h"
#include "nextpnr.h"

NEXTPNR_NAMESPACE_BEGIN
namespace BaseConfigs {
void config_empty_lfe5u_25f(ChipConfig &cc)
{
    cc.chip_name = "LFE5U-25F";
    cc.tiles["CIB_R49C3:CIB_PLL3"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R49C3:CIB_PLL3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C42:VCIB_DCU0"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R49C42:VCIB_DCU0"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R49C42:VCIB_DCU0"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R49C42:VCIB_DCU0"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R49C42:VCIB_DCU0"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R49C42:VCIB_DCU0"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C42:VCIB_DCU0"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R49C42:VCIB_DCU0"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R49C42:VCIB_DCU0"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R49C42:VCIB_DCU0"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R49C42:VCIB_DCU0"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R49C42:VCIB_DCU0"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R49C42:VCIB_DCU0"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R49C42:VCIB_DCU0"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R49C42:VCIB_DCU0"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R49C42:VCIB_DCU0"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R49C43:VCIB_DCUA"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R49C43:VCIB_DCUA"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R49C43:VCIB_DCUA"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R49C43:VCIB_DCUA"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R49C43:VCIB_DCUA"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R49C43:VCIB_DCUA"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C43:VCIB_DCUA"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R49C43:VCIB_DCUA"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R49C43:VCIB_DCUA"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R49C43:VCIB_DCUA"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R49C43:VCIB_DCUA"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R49C43:VCIB_DCUA"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R49C43:VCIB_DCUA"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R49C43:VCIB_DCUA"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R49C43:VCIB_DCUA"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R49C43:VCIB_DCUA"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R49C44:VCIB_DCUB"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R49C44:VCIB_DCUB"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R49C44:VCIB_DCUB"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R49C44:VCIB_DCUB"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R49C44:VCIB_DCUB"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R49C44:VCIB_DCUB"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C44:VCIB_DCUB"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R49C44:VCIB_DCUB"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R49C44:VCIB_DCUB"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R49C44:VCIB_DCUB"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R49C44:VCIB_DCUB"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R49C44:VCIB_DCUB"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R49C44:VCIB_DCUB"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R49C44:VCIB_DCUB"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R49C44:VCIB_DCUB"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R49C44:VCIB_DCUB"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R49C45:VCIB_DCUC"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R49C45:VCIB_DCUC"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R49C45:VCIB_DCUC"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R49C45:VCIB_DCUC"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R49C45:VCIB_DCUC"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R49C45:VCIB_DCUC"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C45:VCIB_DCUC"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R49C45:VCIB_DCUC"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R49C45:VCIB_DCUC"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R49C45:VCIB_DCUC"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R49C45:VCIB_DCUC"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R49C45:VCIB_DCUC"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R49C45:VCIB_DCUC"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R49C45:VCIB_DCUC"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R49C45:VCIB_DCUC"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R49C45:VCIB_DCUC"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R49C46:VCIB_DCUD"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R49C46:VCIB_DCUD"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R49C46:VCIB_DCUD"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R49C46:VCIB_DCUD"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R49C46:VCIB_DCUD"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C46:VCIB_DCUD"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R49C46:VCIB_DCUD"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R49C46:VCIB_DCUD"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R49C46:VCIB_DCUD"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R49C46:VCIB_DCUD"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R49C46:VCIB_DCUD"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R49C46:VCIB_DCUD"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R49C46:VCIB_DCUD"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R49C46:VCIB_DCUD"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R49C46:VCIB_DCUD"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R49C47:VCIB_DCUF"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R49C47:VCIB_DCUF"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R49C47:VCIB_DCUF"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R49C47:VCIB_DCUF"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R49C47:VCIB_DCUF"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R49C47:VCIB_DCUF"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C47:VCIB_DCUF"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R49C47:VCIB_DCUF"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R49C47:VCIB_DCUF"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R49C47:VCIB_DCUF"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R49C47:VCIB_DCUF"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R49C47:VCIB_DCUF"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R49C47:VCIB_DCUF"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R49C47:VCIB_DCUF"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R49C47:VCIB_DCUF"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R49C47:VCIB_DCUF"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R49C48:VCIB_DCU3"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R49C48:VCIB_DCU3"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R49C48:VCIB_DCU3"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R49C48:VCIB_DCU3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C48:VCIB_DCU3"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R49C48:VCIB_DCU3"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R49C48:VCIB_DCU3"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R49C48:VCIB_DCU3"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R49C48:VCIB_DCU3"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R49C48:VCIB_DCU3"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R49C48:VCIB_DCU3"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R49C48:VCIB_DCU3"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R49C48:VCIB_DCU3"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R49C49:VCIB_DCU2"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R49C49:VCIB_DCU2"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C49:VCIB_DCU2"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R49C49:VCIB_DCU2"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R49C49:VCIB_DCU2"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R49C49:VCIB_DCU2"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R49C49:VCIB_DCU2"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R49C49:VCIB_DCU2"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R49C50:VCIB_DCUG"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R49C50:VCIB_DCUG"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C50:VCIB_DCUG"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R49C50:VCIB_DCUG"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R49C50:VCIB_DCUG"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R49C50:VCIB_DCUG"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R49C50:VCIB_DCUG"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R49C50:VCIB_DCUG"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R49C51:VCIB_DCUH"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R49C51:VCIB_DCUH"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C51:VCIB_DCUH"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R49C51:VCIB_DCUH"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R49C51:VCIB_DCUH"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R49C51:VCIB_DCUH"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R49C51:VCIB_DCUH"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R49C51:VCIB_DCUH"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R49C52:VCIB_DCUI"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R49C52:VCIB_DCUI"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C52:VCIB_DCUI"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R49C52:VCIB_DCUI"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R49C52:VCIB_DCUI"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R49C52:VCIB_DCUI"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R49C52:VCIB_DCUI"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R49C52:VCIB_DCUI"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R49C53:VCIB_DCU1"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R49C53:VCIB_DCU1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C53:VCIB_DCU1"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R49C53:VCIB_DCU1"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R49C53:VCIB_DCU1"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R49C69:CIB_PLL3"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R49C69:CIB_PLL3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C6:CIB_EFB0"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C6:CIB_EFB0"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R49C6:CIB_EFB0"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JA4MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JA6MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JB4MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JB6MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JC3MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JC5MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JD3MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JD5MUX", "0");
    cc.tiles["MIB_R13C31:CMUX_UL_0"].add_arc("G_DCS0CLK0", "G_VPFN0000");
    cc.tiles["MIB_R13C32:CMUX_UR_0"].add_arc("G_DCS0CLK1", "G_VPFN0000");
    cc.tiles["MIB_R13C3:DSP_SPINE_UL1"].add_unknown(2, 0);
    cc.tiles["MIB_R13C3:DSP_SPINE_UL1"].add_unknown(3, 0);
    cc.tiles["MIB_R13C3:DSP_SPINE_UL1"].add_unknown(5, 0);
    cc.tiles["MIB_R13C3:DSP_SPINE_UL1"].add_unknown(11, 0);
    cc.tiles["MIB_R13C3:DSP_SPINE_UL1"].add_unknown(13, 0);
    cc.tiles["MIB_R37C31:CMUX_LL_0"].add_arc("G_DCS1CLK0", "G_VPFN0000");
    cc.tiles["MIB_R37C32:CMUX_LR_0"].add_arc("G_DCS1CLK1", "G_VPFN0000");
    cc.tiles["MIB_R50C4:EFB0_PICB0"].add_unknown(54, 1);
    cc.tiles["MIB_R50C4:EFB0_PICB0"].add_unknown(56, 1);
    cc.tiles["MIB_R50C4:EFB0_PICB0"].add_unknown(82, 1);
    cc.tiles["MIB_R50C4:EFB0_PICB0"].add_unknown(94, 1);
}

void config_empty_lfe5u_45f(ChipConfig &cc)
{
    cc.chip_name = "LFE5U-45F";
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(2, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(3, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(5, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(11, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(13, 0);
    cc.tiles["CIB_R5C1:CIB_PLL1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R5C1:CIB_PLL1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R5C89:CIB_PLL1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R5C89:CIB_PLL1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C3:CIB_PLL3"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R70C3:CIB_PLL3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C42:VCIB_DCU0"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R70C42:VCIB_DCU0"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R70C42:VCIB_DCU0"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R70C42:VCIB_DCU0"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R70C42:VCIB_DCU0"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C42:VCIB_DCU0"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C42:VCIB_DCU0"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C42:VCIB_DCU0"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C42:VCIB_DCU0"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R70C42:VCIB_DCU0"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R70C42:VCIB_DCU0"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R70C42:VCIB_DCU0"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R70C42:VCIB_DCU0"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C42:VCIB_DCU0"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C42:VCIB_DCU0"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C42:VCIB_DCU0"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C43:VCIB_DCUA"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R70C43:VCIB_DCUA"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R70C43:VCIB_DCUA"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R70C43:VCIB_DCUA"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R70C43:VCIB_DCUA"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C43:VCIB_DCUA"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C43:VCIB_DCUA"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C43:VCIB_DCUA"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C43:VCIB_DCUA"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R70C43:VCIB_DCUA"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R70C43:VCIB_DCUA"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R70C43:VCIB_DCUA"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R70C43:VCIB_DCUA"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C43:VCIB_DCUA"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C43:VCIB_DCUA"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C43:VCIB_DCUA"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C44:VCIB_DCUB"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R70C44:VCIB_DCUB"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R70C44:VCIB_DCUB"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R70C44:VCIB_DCUB"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R70C44:VCIB_DCUB"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C44:VCIB_DCUB"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C44:VCIB_DCUB"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C44:VCIB_DCUB"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C44:VCIB_DCUB"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R70C44:VCIB_DCUB"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R70C44:VCIB_DCUB"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R70C44:VCIB_DCUB"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R70C44:VCIB_DCUB"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C44:VCIB_DCUB"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C44:VCIB_DCUB"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C44:VCIB_DCUB"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C45:VCIB_DCUC"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R70C45:VCIB_DCUC"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R70C45:VCIB_DCUC"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R70C45:VCIB_DCUC"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R70C45:VCIB_DCUC"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C45:VCIB_DCUC"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C45:VCIB_DCUC"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C45:VCIB_DCUC"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C45:VCIB_DCUC"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R70C45:VCIB_DCUC"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R70C45:VCIB_DCUC"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R70C45:VCIB_DCUC"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R70C45:VCIB_DCUC"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C45:VCIB_DCUC"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C45:VCIB_DCUC"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C45:VCIB_DCUC"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C46:VCIB_DCUD"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R70C46:VCIB_DCUD"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R70C46:VCIB_DCUD"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R70C46:VCIB_DCUD"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C46:VCIB_DCUD"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C46:VCIB_DCUD"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C46:VCIB_DCUD"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C46:VCIB_DCUD"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R70C46:VCIB_DCUD"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R70C46:VCIB_DCUD"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R70C46:VCIB_DCUD"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R70C46:VCIB_DCUD"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C46:VCIB_DCUD"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C46:VCIB_DCUD"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C46:VCIB_DCUD"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C47:VCIB_DCUF"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R70C47:VCIB_DCUF"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R70C47:VCIB_DCUF"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R70C47:VCIB_DCUF"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R70C47:VCIB_DCUF"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C47:VCIB_DCUF"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C47:VCIB_DCUF"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C47:VCIB_DCUF"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C47:VCIB_DCUF"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R70C47:VCIB_DCUF"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R70C47:VCIB_DCUF"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R70C47:VCIB_DCUF"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R70C47:VCIB_DCUF"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C47:VCIB_DCUF"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C47:VCIB_DCUF"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C47:VCIB_DCUF"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C48:VCIB_DCU3"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R70C48:VCIB_DCU3"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R70C48:VCIB_DCU3"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C48:VCIB_DCU3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C48:VCIB_DCU3"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C48:VCIB_DCU3"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C48:VCIB_DCU3"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R70C48:VCIB_DCU3"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R70C48:VCIB_DCU3"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R70C48:VCIB_DCU3"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C48:VCIB_DCU3"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C48:VCIB_DCU3"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C48:VCIB_DCU3"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C49:VCIB_DCU2"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C49:VCIB_DCU2"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C49:VCIB_DCU2"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C49:VCIB_DCU2"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C49:VCIB_DCU2"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C49:VCIB_DCU2"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C49:VCIB_DCU2"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C49:VCIB_DCU2"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C50:VCIB_DCUG"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C50:VCIB_DCUG"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C50:VCIB_DCUG"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C50:VCIB_DCUG"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C50:VCIB_DCUG"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C50:VCIB_DCUG"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C50:VCIB_DCUG"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C50:VCIB_DCUG"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C51:VCIB_DCUH"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C51:VCIB_DCUH"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C51:VCIB_DCUH"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C51:VCIB_DCUH"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C51:VCIB_DCUH"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C51:VCIB_DCUH"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C51:VCIB_DCUH"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C51:VCIB_DCUH"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C52:VCIB_DCUI"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C52:VCIB_DCUI"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C52:VCIB_DCUI"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C52:VCIB_DCUI"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C52:VCIB_DCUI"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C52:VCIB_DCUI"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C52:VCIB_DCUI"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C52:VCIB_DCUI"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C53:VCIB_DCU1"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C53:VCIB_DCU1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C53:VCIB_DCU1"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C53:VCIB_DCU1"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C53:VCIB_DCU1"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C69:VCIB_DCU0"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R70C69:VCIB_DCU0"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R70C69:VCIB_DCU0"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R70C69:VCIB_DCU0"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R70C69:VCIB_DCU0"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C69:VCIB_DCU0"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C69:VCIB_DCU0"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C69:VCIB_DCU0"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C69:VCIB_DCU0"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R70C69:VCIB_DCU0"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R70C69:VCIB_DCU0"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R70C69:VCIB_DCU0"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R70C69:VCIB_DCU0"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C69:VCIB_DCU0"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C69:VCIB_DCU0"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C69:VCIB_DCU0"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C6:CIB_EFB0"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C6:CIB_EFB0"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R70C6:CIB_EFB0"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C70:VCIB_DCUA"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R70C70:VCIB_DCUA"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R70C70:VCIB_DCUA"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R70C70:VCIB_DCUA"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R70C70:VCIB_DCUA"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C70:VCIB_DCUA"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C70:VCIB_DCUA"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C70:VCIB_DCUA"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C70:VCIB_DCUA"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R70C70:VCIB_DCUA"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R70C70:VCIB_DCUA"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R70C70:VCIB_DCUA"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R70C70:VCIB_DCUA"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C70:VCIB_DCUA"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C70:VCIB_DCUA"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C70:VCIB_DCUA"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C71:VCIB_DCUB"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R70C71:VCIB_DCUB"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R70C71:VCIB_DCUB"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R70C71:VCIB_DCUB"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R70C71:VCIB_DCUB"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C71:VCIB_DCUB"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C71:VCIB_DCUB"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C71:VCIB_DCUB"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C71:VCIB_DCUB"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R70C71:VCIB_DCUB"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R70C71:VCIB_DCUB"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R70C71:VCIB_DCUB"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R70C71:VCIB_DCUB"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C71:VCIB_DCUB"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C71:VCIB_DCUB"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C71:VCIB_DCUB"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C72:VCIB_DCUC"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R70C72:VCIB_DCUC"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R70C72:VCIB_DCUC"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R70C72:VCIB_DCUC"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R70C72:VCIB_DCUC"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C72:VCIB_DCUC"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C72:VCIB_DCUC"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C72:VCIB_DCUC"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C72:VCIB_DCUC"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R70C72:VCIB_DCUC"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R70C72:VCIB_DCUC"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R70C72:VCIB_DCUC"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R70C72:VCIB_DCUC"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C72:VCIB_DCUC"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C72:VCIB_DCUC"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C72:VCIB_DCUC"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C73:VCIB_DCUD"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R70C73:VCIB_DCUD"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R70C73:VCIB_DCUD"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R70C73:VCIB_DCUD"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C73:VCIB_DCUD"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C73:VCIB_DCUD"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C73:VCIB_DCUD"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C73:VCIB_DCUD"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R70C73:VCIB_DCUD"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R70C73:VCIB_DCUD"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R70C73:VCIB_DCUD"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R70C73:VCIB_DCUD"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C73:VCIB_DCUD"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C73:VCIB_DCUD"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C73:VCIB_DCUD"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C74:VCIB_DCUF"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R70C74:VCIB_DCUF"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R70C74:VCIB_DCUF"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R70C74:VCIB_DCUF"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R70C74:VCIB_DCUF"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C74:VCIB_DCUF"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C74:VCIB_DCUF"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C74:VCIB_DCUF"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C74:VCIB_DCUF"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R70C74:VCIB_DCUF"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R70C74:VCIB_DCUF"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R70C74:VCIB_DCUF"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R70C74:VCIB_DCUF"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C74:VCIB_DCUF"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C74:VCIB_DCUF"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C74:VCIB_DCUF"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C75:VCIB_DCU3"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R70C75:VCIB_DCU3"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R70C75:VCIB_DCU3"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C75:VCIB_DCU3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C75:VCIB_DCU3"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C75:VCIB_DCU3"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C75:VCIB_DCU3"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R70C75:VCIB_DCU3"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R70C75:VCIB_DCU3"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R70C75:VCIB_DCU3"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C75:VCIB_DCU3"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C75:VCIB_DCU3"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C75:VCIB_DCU3"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C76:VCIB_DCU2"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C76:VCIB_DCU2"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C76:VCIB_DCU2"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C76:VCIB_DCU2"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C76:VCIB_DCU2"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C76:VCIB_DCU2"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C76:VCIB_DCU2"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C76:VCIB_DCU2"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C77:VCIB_DCUG"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C77:VCIB_DCUG"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C77:VCIB_DCUG"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C77:VCIB_DCUG"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C77:VCIB_DCUG"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C77:VCIB_DCUG"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C77:VCIB_DCUG"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C77:VCIB_DCUG"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C78:VCIB_DCUH"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C78:VCIB_DCUH"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C78:VCIB_DCUH"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C78:VCIB_DCUH"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C78:VCIB_DCUH"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C78:VCIB_DCUH"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C78:VCIB_DCUH"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C78:VCIB_DCUH"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C79:VCIB_DCUI"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C79:VCIB_DCUI"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C79:VCIB_DCUI"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C79:VCIB_DCUI"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R70C79:VCIB_DCUI"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C79:VCIB_DCUI"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C79:VCIB_DCUI"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C79:VCIB_DCUI"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JA4MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JA6MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JB4MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JB6MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JC3MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JC5MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JD3MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JD5MUX", "0");
    cc.tiles["CIB_R70C80:VCIB_DCU1"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R70C80:VCIB_DCU1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C80:VCIB_DCU1"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C80:VCIB_DCU1"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R70C80:VCIB_DCU1"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R70C87:CIB_PLL3"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R70C87:CIB_PLL3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["MIB_R10C40:CMUX_UL_0"].add_arc("G_DCS0CLK0", "G_VPFN0000");
    cc.tiles["MIB_R10C41:CMUX_UR_0"].add_arc("G_DCS0CLK1", "G_VPFN0000");
    cc.tiles["MIB_R58C40:CMUX_LL_0"].add_arc("G_DCS1CLK0", "G_VPFN0000");
    cc.tiles["MIB_R58C41:CMUX_LR_0"].add_arc("G_DCS1CLK1", "G_VPFN0000");
    cc.tiles["MIB_R71C4:EFB0_PICB0"].add_unknown(54, 1);
    cc.tiles["MIB_R71C4:EFB0_PICB0"].add_unknown(56, 1);
    cc.tiles["MIB_R71C4:EFB0_PICB0"].add_unknown(82, 1);
    cc.tiles["MIB_R71C4:EFB0_PICB0"].add_unknown(94, 1);
}

void config_empty_lfe5u_85f(ChipConfig &cc)
{
    cc.chip_name = "LFE5U-85F";
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(2, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(3, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(5, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(11, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(13, 0);
    cc.tiles["CIB_R5C125:CIB_PLL1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R5C125:CIB_PLL1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R5C1:CIB_PLL1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R5C1:CIB_PLL1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C123:CIB_PLL3"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R94C123:CIB_PLL3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C3:CIB_PLL3"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R94C3:CIB_PLL3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C46:VCIB_DCU0"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R94C46:VCIB_DCU0"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R94C46:VCIB_DCU0"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R94C46:VCIB_DCU0"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R94C46:VCIB_DCU0"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C46:VCIB_DCU0"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C46:VCIB_DCU0"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C46:VCIB_DCU0"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C46:VCIB_DCU0"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R94C46:VCIB_DCU0"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R94C46:VCIB_DCU0"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R94C46:VCIB_DCU0"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R94C46:VCIB_DCU0"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C46:VCIB_DCU0"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C46:VCIB_DCU0"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C46:VCIB_DCU0"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C47:VCIB_DCUA"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R94C47:VCIB_DCUA"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R94C47:VCIB_DCUA"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R94C47:VCIB_DCUA"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R94C47:VCIB_DCUA"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C47:VCIB_DCUA"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C47:VCIB_DCUA"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C47:VCIB_DCUA"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C47:VCIB_DCUA"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R94C47:VCIB_DCUA"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R94C47:VCIB_DCUA"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R94C47:VCIB_DCUA"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R94C47:VCIB_DCUA"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C47:VCIB_DCUA"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C47:VCIB_DCUA"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C47:VCIB_DCUA"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C48:VCIB_DCUB"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R94C48:VCIB_DCUB"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R94C48:VCIB_DCUB"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R94C48:VCIB_DCUB"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R94C48:VCIB_DCUB"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C48:VCIB_DCUB"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C48:VCIB_DCUB"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C48:VCIB_DCUB"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C48:VCIB_DCUB"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R94C48:VCIB_DCUB"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R94C48:VCIB_DCUB"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R94C48:VCIB_DCUB"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R94C48:VCIB_DCUB"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C48:VCIB_DCUB"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C48:VCIB_DCUB"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C48:VCIB_DCUB"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C49:VCIB_DCUC"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R94C49:VCIB_DCUC"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R94C49:VCIB_DCUC"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R94C49:VCIB_DCUC"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R94C49:VCIB_DCUC"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C49:VCIB_DCUC"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C49:VCIB_DCUC"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C49:VCIB_DCUC"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C49:VCIB_DCUC"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R94C49:VCIB_DCUC"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R94C49:VCIB_DCUC"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R94C49:VCIB_DCUC"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R94C49:VCIB_DCUC"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C49:VCIB_DCUC"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C49:VCIB_DCUC"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C49:VCIB_DCUC"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C50:VCIB_DCUD"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R94C50:VCIB_DCUD"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R94C50:VCIB_DCUD"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R94C50:VCIB_DCUD"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C50:VCIB_DCUD"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C50:VCIB_DCUD"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C50:VCIB_DCUD"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C50:VCIB_DCUD"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R94C50:VCIB_DCUD"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R94C50:VCIB_DCUD"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R94C50:VCIB_DCUD"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R94C50:VCIB_DCUD"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C50:VCIB_DCUD"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C50:VCIB_DCUD"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C50:VCIB_DCUD"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C51:VCIB_DCUF"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R94C51:VCIB_DCUF"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R94C51:VCIB_DCUF"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R94C51:VCIB_DCUF"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R94C51:VCIB_DCUF"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C51:VCIB_DCUF"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C51:VCIB_DCUF"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C51:VCIB_DCUF"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C51:VCIB_DCUF"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R94C51:VCIB_DCUF"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R94C51:VCIB_DCUF"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R94C51:VCIB_DCUF"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R94C51:VCIB_DCUF"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C51:VCIB_DCUF"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C51:VCIB_DCUF"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C51:VCIB_DCUF"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C52:VCIB_DCU3"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R94C52:VCIB_DCU3"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R94C52:VCIB_DCU3"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C52:VCIB_DCU3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C52:VCIB_DCU3"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C52:VCIB_DCU3"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C52:VCIB_DCU3"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R94C52:VCIB_DCU3"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R94C52:VCIB_DCU3"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R94C52:VCIB_DCU3"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C52:VCIB_DCU3"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C52:VCIB_DCU3"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C52:VCIB_DCU3"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C53:VCIB_DCU2"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C53:VCIB_DCU2"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C53:VCIB_DCU2"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C53:VCIB_DCU2"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C53:VCIB_DCU2"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C53:VCIB_DCU2"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C53:VCIB_DCU2"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C53:VCIB_DCU2"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C54:VCIB_DCUG"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C54:VCIB_DCUG"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C54:VCIB_DCUG"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C54:VCIB_DCUG"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C54:VCIB_DCUG"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C54:VCIB_DCUG"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C54:VCIB_DCUG"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C54:VCIB_DCUG"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C55:VCIB_DCUH"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C55:VCIB_DCUH"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C55:VCIB_DCUH"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C55:VCIB_DCUH"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C55:VCIB_DCUH"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C55:VCIB_DCUH"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C55:VCIB_DCUH"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C55:VCIB_DCUH"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C56:VCIB_DCUI"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C56:VCIB_DCUI"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C56:VCIB_DCUI"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C56:VCIB_DCUI"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C56:VCIB_DCUI"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C56:VCIB_DCUI"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C56:VCIB_DCUI"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C56:VCIB_DCUI"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C57:VCIB_DCU1"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C57:VCIB_DCU1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C57:VCIB_DCU1"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C57:VCIB_DCU1"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C57:VCIB_DCU1"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C6:CIB_EFB0"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C6:CIB_EFB0"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R94C6:CIB_EFB0"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C71:VCIB_DCU0"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R94C71:VCIB_DCU0"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R94C71:VCIB_DCU0"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R94C71:VCIB_DCU0"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R94C71:VCIB_DCU0"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C71:VCIB_DCU0"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C71:VCIB_DCU0"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C71:VCIB_DCU0"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C71:VCIB_DCU0"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R94C71:VCIB_DCU0"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R94C71:VCIB_DCU0"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R94C71:VCIB_DCU0"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R94C71:VCIB_DCU0"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C71:VCIB_DCU0"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C71:VCIB_DCU0"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C71:VCIB_DCU0"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C72:VCIB_DCUA"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R94C72:VCIB_DCUA"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R94C72:VCIB_DCUA"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R94C72:VCIB_DCUA"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R94C72:VCIB_DCUA"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C72:VCIB_DCUA"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C72:VCIB_DCUA"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C72:VCIB_DCUA"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C72:VCIB_DCUA"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R94C72:VCIB_DCUA"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R94C72:VCIB_DCUA"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R94C72:VCIB_DCUA"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R94C72:VCIB_DCUA"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C72:VCIB_DCUA"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C72:VCIB_DCUA"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C72:VCIB_DCUA"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C73:VCIB_DCUB"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R94C73:VCIB_DCUB"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R94C73:VCIB_DCUB"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R94C73:VCIB_DCUB"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R94C73:VCIB_DCUB"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C73:VCIB_DCUB"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C73:VCIB_DCUB"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C73:VCIB_DCUB"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C73:VCIB_DCUB"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R94C73:VCIB_DCUB"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R94C73:VCIB_DCUB"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R94C73:VCIB_DCUB"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R94C73:VCIB_DCUB"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C73:VCIB_DCUB"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C73:VCIB_DCUB"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C73:VCIB_DCUB"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C74:VCIB_DCUC"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R94C74:VCIB_DCUC"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R94C74:VCIB_DCUC"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R94C74:VCIB_DCUC"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R94C74:VCIB_DCUC"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C74:VCIB_DCUC"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C74:VCIB_DCUC"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C74:VCIB_DCUC"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C74:VCIB_DCUC"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R94C74:VCIB_DCUC"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R94C74:VCIB_DCUC"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R94C74:VCIB_DCUC"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R94C74:VCIB_DCUC"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C74:VCIB_DCUC"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C74:VCIB_DCUC"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C74:VCIB_DCUC"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C75:VCIB_DCUD"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R94C75:VCIB_DCUD"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R94C75:VCIB_DCUD"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R94C75:VCIB_DCUD"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C75:VCIB_DCUD"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C75:VCIB_DCUD"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C75:VCIB_DCUD"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C75:VCIB_DCUD"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R94C75:VCIB_DCUD"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R94C75:VCIB_DCUD"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R94C75:VCIB_DCUD"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R94C75:VCIB_DCUD"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C75:VCIB_DCUD"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C75:VCIB_DCUD"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C75:VCIB_DCUD"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C76:VCIB_DCUF"].add_enum("CIB.JA1MUX", "0");
    cc.tiles["CIB_R94C76:VCIB_DCUF"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R94C76:VCIB_DCUF"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R94C76:VCIB_DCUF"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R94C76:VCIB_DCUF"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C76:VCIB_DCUF"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C76:VCIB_DCUF"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C76:VCIB_DCUF"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C76:VCIB_DCUF"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R94C76:VCIB_DCUF"].add_enum("CIB.JC2MUX", "0");
    cc.tiles["CIB_R94C76:VCIB_DCUF"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R94C76:VCIB_DCUF"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R94C76:VCIB_DCUF"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C76:VCIB_DCUF"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C76:VCIB_DCUF"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C76:VCIB_DCUF"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C77:VCIB_DCU3"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R94C77:VCIB_DCU3"].add_enum("CIB.JA7MUX", "0");
    cc.tiles["CIB_R94C77:VCIB_DCU3"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C77:VCIB_DCU3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C77:VCIB_DCU3"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C77:VCIB_DCU3"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C77:VCIB_DCU3"].add_enum("CIB.JC0MUX", "0");
    cc.tiles["CIB_R94C77:VCIB_DCU3"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R94C77:VCIB_DCU3"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R94C77:VCIB_DCU3"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C77:VCIB_DCU3"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C77:VCIB_DCU3"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C77:VCIB_DCU3"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C78:VCIB_DCU2"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C78:VCIB_DCU2"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C78:VCIB_DCU2"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C78:VCIB_DCU2"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C78:VCIB_DCU2"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C78:VCIB_DCU2"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C78:VCIB_DCU2"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C78:VCIB_DCU2"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C79:VCIB_DCUG"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C79:VCIB_DCUG"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C79:VCIB_DCUG"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C79:VCIB_DCUG"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C79:VCIB_DCUG"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C79:VCIB_DCUG"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C79:VCIB_DCUG"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C79:VCIB_DCUG"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JA4MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JA6MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JB4MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JB6MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JC3MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JC5MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JD3MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JD5MUX", "0");
    cc.tiles["CIB_R94C80:VCIB_DCUH"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C80:VCIB_DCUH"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C80:VCIB_DCUH"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C80:VCIB_DCUH"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C80:VCIB_DCUH"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C80:VCIB_DCUH"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C80:VCIB_DCUH"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C80:VCIB_DCUH"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C81:VCIB_DCUI"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C81:VCIB_DCUI"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C81:VCIB_DCUI"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C81:VCIB_DCUI"].add_enum("CIB.JB7MUX", "0");
    cc.tiles["CIB_R94C81:VCIB_DCUI"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C81:VCIB_DCUI"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["CIB_R94C81:VCIB_DCUI"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C81:VCIB_DCUI"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C82:VCIB_DCU1"].add_enum("CIB.JB1MUX", "0");
    cc.tiles["CIB_R94C82:VCIB_DCU1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C82:VCIB_DCU1"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C82:VCIB_DCU1"].add_enum("CIB.JD0MUX", "0");
    cc.tiles["CIB_R94C82:VCIB_DCU1"].add_enum("CIB.JD2MUX", "0");
    cc.tiles["MIB_R22C67:CMUX_UL_0"].add_arc("G_DCS0CLK0", "G_VPFN0000");
    cc.tiles["MIB_R22C68:CMUX_UR_0"].add_arc("G_DCS0CLK1", "G_VPFN0000");
    cc.tiles["MIB_R70C67:CMUX_LL_0"].add_arc("G_DCS1CLK0", "G_VPFN0000");
    cc.tiles["MIB_R70C68:CMUX_LR_0"].add_arc("G_DCS1CLK1", "G_VPFN0000");
    cc.tiles["MIB_R95C101:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C102:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C103:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C104:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C105:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C106:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C107:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C108:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C110:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C111:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C112:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C113:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C114:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C115:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C116:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C117:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C119:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C120:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C121:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C122:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C4:EFB0_PICB0"].add_unknown(54, 1);
    cc.tiles["MIB_R95C4:EFB0_PICB0"].add_unknown(56, 1);
    cc.tiles["MIB_R95C4:EFB0_PICB0"].add_unknown(82, 1);
    cc.tiles["MIB_R95C4:EFB0_PICB0"].add_unknown(94, 1);
    cc.tiles["MIB_R95C96:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C97:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C98:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C99:PICB1"].add_unknown(0, 1);
}

void config_empty_lfe5um_25f(ChipConfig &cc)
{
    cc.chip_name = "LFE5UM-25F";
    cc.tiles["CIB_R49C3:CIB_PLL3"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R49C3:CIB_PLL3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(20, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(21, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(22, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(23, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(28, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(29, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(30, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(31, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(74, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(75, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(76, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(77, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(82, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(83, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(84, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(85, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(20, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(21, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(22, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(23, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(28, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(29, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(30, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(31, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(74, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(75, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(76, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(77, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(82, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(83, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(84, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(85, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(20, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(21, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(22, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(23, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(28, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(29, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(30, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(31, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(74, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(75, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(76, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(77, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(82, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(83, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(84, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(85, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(20, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(21, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(22, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(23, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(28, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(29, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(30, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(31, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(74, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(75, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(76, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(77, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(82, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(83, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(84, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(85, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(20, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(21, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(22, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(23, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(28, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(29, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(31, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(74, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(75, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(76, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(77, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(82, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(83, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(84, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(85, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(20, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(21, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(22, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(23, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(28, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(29, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(30, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(31, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(74, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(75, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(76, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(77, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(82, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(83, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(84, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(85, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(20, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(22, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(23, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(29, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(31, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(74, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(75, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(76, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(77, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(82, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(83, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(84, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(85, 10);
    cc.tiles["CIB_R49C49:CIB_DCU2"].add_unknown(20, 10);
    cc.tiles["CIB_R49C49:CIB_DCU2"].add_unknown(22, 10);
    cc.tiles["CIB_R49C49:CIB_DCU2"].add_unknown(29, 10);
    cc.tiles["CIB_R49C49:CIB_DCU2"].add_unknown(31, 10);
    cc.tiles["CIB_R49C49:CIB_DCU2"].add_unknown(74, 10);
    cc.tiles["CIB_R49C49:CIB_DCU2"].add_unknown(76, 10);
    cc.tiles["CIB_R49C49:CIB_DCU2"].add_unknown(83, 10);
    cc.tiles["CIB_R49C49:CIB_DCU2"].add_unknown(85, 10);
    cc.tiles["CIB_R49C50:CIB_DCUG"].add_unknown(20, 10);
    cc.tiles["CIB_R49C50:CIB_DCUG"].add_unknown(22, 10);
    cc.tiles["CIB_R49C50:CIB_DCUG"].add_unknown(29, 10);
    cc.tiles["CIB_R49C50:CIB_DCUG"].add_unknown(31, 10);
    cc.tiles["CIB_R49C50:CIB_DCUG"].add_unknown(74, 10);
    cc.tiles["CIB_R49C50:CIB_DCUG"].add_unknown(76, 10);
    cc.tiles["CIB_R49C50:CIB_DCUG"].add_unknown(83, 10);
    cc.tiles["CIB_R49C50:CIB_DCUG"].add_unknown(85, 10);
    cc.tiles["CIB_R49C51:CIB_DCUH"].add_unknown(20, 10);
    cc.tiles["CIB_R49C51:CIB_DCUH"].add_unknown(22, 10);
    cc.tiles["CIB_R49C51:CIB_DCUH"].add_unknown(29, 10);
    cc.tiles["CIB_R49C51:CIB_DCUH"].add_unknown(31, 10);
    cc.tiles["CIB_R49C51:CIB_DCUH"].add_unknown(74, 10);
    cc.tiles["CIB_R49C51:CIB_DCUH"].add_unknown(76, 10);
    cc.tiles["CIB_R49C51:CIB_DCUH"].add_unknown(83, 10);
    cc.tiles["CIB_R49C51:CIB_DCUH"].add_unknown(85, 10);
    cc.tiles["CIB_R49C52:CIB_DCUI"].add_unknown(20, 10);
    cc.tiles["CIB_R49C52:CIB_DCUI"].add_unknown(22, 10);
    cc.tiles["CIB_R49C52:CIB_DCUI"].add_unknown(29, 10);
    cc.tiles["CIB_R49C52:CIB_DCUI"].add_unknown(31, 10);
    cc.tiles["CIB_R49C52:CIB_DCUI"].add_unknown(74, 10);
    cc.tiles["CIB_R49C52:CIB_DCUI"].add_unknown(76, 10);
    cc.tiles["CIB_R49C52:CIB_DCUI"].add_unknown(83, 10);
    cc.tiles["CIB_R49C52:CIB_DCUI"].add_unknown(85, 10);
    cc.tiles["CIB_R49C53:CIB_DCU1"].add_unknown(20, 10);
    cc.tiles["CIB_R49C53:CIB_DCU1"].add_unknown(22, 10);
    cc.tiles["CIB_R49C53:CIB_DCU1"].add_unknown(29, 10);
    cc.tiles["CIB_R49C53:CIB_DCU1"].add_unknown(31, 10);
    cc.tiles["CIB_R49C53:CIB_DCU1"].add_unknown(74, 10);
    cc.tiles["CIB_R49C69:CIB_PLL3"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R49C69:CIB_PLL3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C6:CIB_EFB0"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C6:CIB_EFB0"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R49C6:CIB_EFB0"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JA4MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JA6MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JB4MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JB6MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JC3MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JC5MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JD3MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JD5MUX", "0");
    cc.tiles["MIB_R13C31:CMUX_UL_0"].add_arc("G_DCS0CLK0", "G_VPFN0000");
    cc.tiles["MIB_R13C32:CMUX_UR_0"].add_arc("G_DCS0CLK1", "G_VPFN0000");
    cc.tiles["MIB_R13C3:DSP_SPINE_UL1"].add_unknown(2, 0);
    cc.tiles["MIB_R13C3:DSP_SPINE_UL1"].add_unknown(3, 0);
    cc.tiles["MIB_R13C3:DSP_SPINE_UL1"].add_unknown(5, 0);
    cc.tiles["MIB_R13C3:DSP_SPINE_UL1"].add_unknown(11, 0);
    cc.tiles["MIB_R13C3:DSP_SPINE_UL1"].add_unknown(13, 0);
    cc.tiles["MIB_R37C31:CMUX_LL_0"].add_arc("G_DCS1CLK0", "G_VPFN0000");
    cc.tiles["MIB_R37C32:CMUX_LR_0"].add_arc("G_DCS1CLK1", "G_VPFN0000");
    cc.tiles["MIB_R50C4:EFB0_PICB0"].add_unknown(54, 1);
    cc.tiles["MIB_R50C4:EFB0_PICB0"].add_unknown(56, 1);
    cc.tiles["MIB_R50C4:EFB0_PICB0"].add_unknown(82, 1);
    cc.tiles["MIB_R50C4:EFB0_PICB0"].add_unknown(94, 1);
}

void config_empty_lfe5um_45f(ChipConfig &cc)
{
    cc.chip_name = "LFE5UM-45F";
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(2, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(3, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(5, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(11, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(13, 0);
    cc.tiles["CIB_R5C1:CIB_PLL1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R5C1:CIB_PLL1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R5C89:CIB_PLL1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R5C89:CIB_PLL1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C3:CIB_PLL3"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R70C3:CIB_PLL3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(20, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(21, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(22, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(23, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(28, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(29, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(30, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(31, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(74, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(75, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(76, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(77, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(82, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(83, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(84, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(85, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(20, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(21, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(22, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(23, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(28, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(29, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(30, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(31, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(74, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(75, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(76, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(77, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(82, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(83, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(84, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(85, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(20, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(21, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(22, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(23, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(28, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(29, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(30, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(31, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(74, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(75, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(76, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(77, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(82, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(83, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(84, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(85, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(20, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(21, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(22, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(23, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(28, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(29, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(30, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(31, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(74, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(75, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(76, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(77, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(82, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(83, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(84, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(85, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(20, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(21, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(22, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(23, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(28, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(29, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(31, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(74, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(75, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(76, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(77, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(82, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(83, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(84, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(85, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(20, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(21, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(22, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(23, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(28, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(29, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(30, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(31, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(74, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(75, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(76, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(77, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(82, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(83, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(84, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(85, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(20, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(22, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(23, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(29, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(31, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(74, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(75, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(76, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(77, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(82, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(83, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(84, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(85, 10);
    cc.tiles["CIB_R70C49:CIB_DCU2"].add_unknown(20, 10);
    cc.tiles["CIB_R70C49:CIB_DCU2"].add_unknown(22, 10);
    cc.tiles["CIB_R70C49:CIB_DCU2"].add_unknown(29, 10);
    cc.tiles["CIB_R70C49:CIB_DCU2"].add_unknown(31, 10);
    cc.tiles["CIB_R70C49:CIB_DCU2"].add_unknown(74, 10);
    cc.tiles["CIB_R70C49:CIB_DCU2"].add_unknown(76, 10);
    cc.tiles["CIB_R70C49:CIB_DCU2"].add_unknown(83, 10);
    cc.tiles["CIB_R70C49:CIB_DCU2"].add_unknown(85, 10);
    cc.tiles["CIB_R70C50:CIB_DCUG"].add_unknown(20, 10);
    cc.tiles["CIB_R70C50:CIB_DCUG"].add_unknown(22, 10);
    cc.tiles["CIB_R70C50:CIB_DCUG"].add_unknown(29, 10);
    cc.tiles["CIB_R70C50:CIB_DCUG"].add_unknown(31, 10);
    cc.tiles["CIB_R70C50:CIB_DCUG"].add_unknown(74, 10);
    cc.tiles["CIB_R70C50:CIB_DCUG"].add_unknown(76, 10);
    cc.tiles["CIB_R70C50:CIB_DCUG"].add_unknown(83, 10);
    cc.tiles["CIB_R70C50:CIB_DCUG"].add_unknown(85, 10);
    cc.tiles["CIB_R70C51:CIB_DCUH"].add_unknown(20, 10);
    cc.tiles["CIB_R70C51:CIB_DCUH"].add_unknown(22, 10);
    cc.tiles["CIB_R70C51:CIB_DCUH"].add_unknown(29, 10);
    cc.tiles["CIB_R70C51:CIB_DCUH"].add_unknown(31, 10);
    cc.tiles["CIB_R70C51:CIB_DCUH"].add_unknown(74, 10);
    cc.tiles["CIB_R70C51:CIB_DCUH"].add_unknown(76, 10);
    cc.tiles["CIB_R70C51:CIB_DCUH"].add_unknown(83, 10);
    cc.tiles["CIB_R70C51:CIB_DCUH"].add_unknown(85, 10);
    cc.tiles["CIB_R70C52:CIB_DCUI"].add_unknown(20, 10);
    cc.tiles["CIB_R70C52:CIB_DCUI"].add_unknown(22, 10);
    cc.tiles["CIB_R70C52:CIB_DCUI"].add_unknown(29, 10);
    cc.tiles["CIB_R70C52:CIB_DCUI"].add_unknown(31, 10);
    cc.tiles["CIB_R70C52:CIB_DCUI"].add_unknown(74, 10);
    cc.tiles["CIB_R70C52:CIB_DCUI"].add_unknown(76, 10);
    cc.tiles["CIB_R70C52:CIB_DCUI"].add_unknown(83, 10);
    cc.tiles["CIB_R70C52:CIB_DCUI"].add_unknown(85, 10);
    cc.tiles["CIB_R70C53:CIB_DCU1"].add_unknown(20, 10);
    cc.tiles["CIB_R70C53:CIB_DCU1"].add_unknown(22, 10);
    cc.tiles["CIB_R70C53:CIB_DCU1"].add_unknown(29, 10);
    cc.tiles["CIB_R70C53:CIB_DCU1"].add_unknown(31, 10);
    cc.tiles["CIB_R70C53:CIB_DCU1"].add_unknown(74, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(20, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(21, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(22, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(23, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(28, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(29, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(30, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(31, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(74, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(75, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(76, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(77, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(82, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(83, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(84, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(85, 10);
    cc.tiles["CIB_R70C6:CIB_EFB0"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C6:CIB_EFB0"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R70C6:CIB_EFB0"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(20, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(21, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(22, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(23, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(28, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(29, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(30, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(31, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(74, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(75, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(76, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(77, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(82, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(83, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(84, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(85, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(20, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(21, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(22, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(23, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(28, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(29, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(30, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(31, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(74, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(75, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(76, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(77, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(82, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(83, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(84, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(85, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(20, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(21, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(22, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(23, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(28, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(29, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(30, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(31, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(74, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(75, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(76, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(77, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(82, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(83, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(84, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(85, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(20, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(21, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(22, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(23, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(28, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(29, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(31, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(74, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(75, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(76, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(77, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(82, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(83, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(84, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(85, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(20, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(21, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(22, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(23, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(28, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(29, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(30, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(31, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(74, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(75, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(76, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(77, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(82, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(83, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(84, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(85, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(20, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(22, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(23, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(29, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(31, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(74, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(75, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(76, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(77, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(82, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(83, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(84, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(85, 10);
    cc.tiles["CIB_R70C76:CIB_DCU2"].add_unknown(20, 10);
    cc.tiles["CIB_R70C76:CIB_DCU2"].add_unknown(22, 10);
    cc.tiles["CIB_R70C76:CIB_DCU2"].add_unknown(29, 10);
    cc.tiles["CIB_R70C76:CIB_DCU2"].add_unknown(31, 10);
    cc.tiles["CIB_R70C76:CIB_DCU2"].add_unknown(74, 10);
    cc.tiles["CIB_R70C76:CIB_DCU2"].add_unknown(76, 10);
    cc.tiles["CIB_R70C76:CIB_DCU2"].add_unknown(83, 10);
    cc.tiles["CIB_R70C76:CIB_DCU2"].add_unknown(85, 10);
    cc.tiles["CIB_R70C77:CIB_DCUG"].add_unknown(20, 10);
    cc.tiles["CIB_R70C77:CIB_DCUG"].add_unknown(22, 10);
    cc.tiles["CIB_R70C77:CIB_DCUG"].add_unknown(29, 10);
    cc.tiles["CIB_R70C77:CIB_DCUG"].add_unknown(31, 10);
    cc.tiles["CIB_R70C77:CIB_DCUG"].add_unknown(74, 10);
    cc.tiles["CIB_R70C77:CIB_DCUG"].add_unknown(76, 10);
    cc.tiles["CIB_R70C77:CIB_DCUG"].add_unknown(83, 10);
    cc.tiles["CIB_R70C77:CIB_DCUG"].add_unknown(85, 10);
    cc.tiles["CIB_R70C78:CIB_DCUH"].add_unknown(20, 10);
    cc.tiles["CIB_R70C78:CIB_DCUH"].add_unknown(22, 10);
    cc.tiles["CIB_R70C78:CIB_DCUH"].add_unknown(29, 10);
    cc.tiles["CIB_R70C78:CIB_DCUH"].add_unknown(31, 10);
    cc.tiles["CIB_R70C78:CIB_DCUH"].add_unknown(74, 10);
    cc.tiles["CIB_R70C78:CIB_DCUH"].add_unknown(76, 10);
    cc.tiles["CIB_R70C78:CIB_DCUH"].add_unknown(83, 10);
    cc.tiles["CIB_R70C78:CIB_DCUH"].add_unknown(85, 10);
    cc.tiles["CIB_R70C79:CIB_DCUI"].add_unknown(20, 10);
    cc.tiles["CIB_R70C79:CIB_DCUI"].add_unknown(22, 10);
    cc.tiles["CIB_R70C79:CIB_DCUI"].add_unknown(29, 10);
    cc.tiles["CIB_R70C79:CIB_DCUI"].add_unknown(31, 10);
    cc.tiles["CIB_R70C79:CIB_DCUI"].add_unknown(74, 10);
    cc.tiles["CIB_R70C79:CIB_DCUI"].add_unknown(76, 10);
    cc.tiles["CIB_R70C79:CIB_DCUI"].add_unknown(83, 10);
    cc.tiles["CIB_R70C79:CIB_DCUI"].add_unknown(85, 10);
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JA4MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JA6MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JB4MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JB6MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JC3MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JC5MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JD3MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JD5MUX", "0");
    cc.tiles["CIB_R70C80:CIB_DCU1"].add_unknown(20, 10);
    cc.tiles["CIB_R70C80:CIB_DCU1"].add_unknown(22, 10);
    cc.tiles["CIB_R70C80:CIB_DCU1"].add_unknown(29, 10);
    cc.tiles["CIB_R70C80:CIB_DCU1"].add_unknown(31, 10);
    cc.tiles["CIB_R70C80:CIB_DCU1"].add_unknown(74, 10);
    cc.tiles["CIB_R70C87:CIB_PLL3"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R70C87:CIB_PLL3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["MIB_R10C40:CMUX_UL_0"].add_arc("G_DCS0CLK0", "G_VPFN0000");
    cc.tiles["MIB_R10C41:CMUX_UR_0"].add_arc("G_DCS0CLK1", "G_VPFN0000");
    cc.tiles["MIB_R58C40:CMUX_LL_0"].add_arc("G_DCS1CLK0", "G_VPFN0000");
    cc.tiles["MIB_R58C41:CMUX_LR_0"].add_arc("G_DCS1CLK1", "G_VPFN0000");
    cc.tiles["MIB_R71C4:EFB0_PICB0"].add_unknown(54, 1);
    cc.tiles["MIB_R71C4:EFB0_PICB0"].add_unknown(56, 1);
    cc.tiles["MIB_R71C4:EFB0_PICB0"].add_unknown(82, 1);
    cc.tiles["MIB_R71C4:EFB0_PICB0"].add_unknown(94, 1);
}

void config_empty_lfe5um5g_25f(ChipConfig &cc)
{
    cc.chip_name = "LFE5UM5G-25F";
    cc.tiles["CIB_R49C3:CIB_PLL3"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R49C3:CIB_PLL3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(20, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(21, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(22, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(23, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(28, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(29, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(30, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(31, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(74, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(75, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(76, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(77, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(82, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(83, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(84, 10);
    cc.tiles["CIB_R49C42:CIB_DCU0"].add_unknown(85, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(20, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(21, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(22, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(23, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(28, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(29, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(30, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(31, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(74, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(75, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(76, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(77, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(82, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(83, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(84, 10);
    cc.tiles["CIB_R49C43:CIB_DCUA"].add_unknown(85, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(20, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(21, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(22, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(23, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(28, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(29, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(30, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(31, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(74, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(75, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(76, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(77, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(82, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(83, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(84, 10);
    cc.tiles["CIB_R49C44:CIB_DCUB"].add_unknown(85, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(20, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(21, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(22, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(23, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(28, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(29, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(30, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(31, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(74, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(75, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(76, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(77, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(82, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(83, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(84, 10);
    cc.tiles["CIB_R49C45:CIB_DCUC"].add_unknown(85, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(20, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(21, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(22, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(23, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(28, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(29, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(31, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(74, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(75, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(76, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(77, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(82, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(83, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(84, 10);
    cc.tiles["CIB_R49C46:CIB_DCUD"].add_unknown(85, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(20, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(21, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(22, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(23, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(28, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(29, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(30, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(31, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(74, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(75, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(76, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(77, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(82, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(83, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(84, 10);
    cc.tiles["CIB_R49C47:CIB_DCUF"].add_unknown(85, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(20, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(22, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(23, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(29, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(31, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(74, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(75, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(76, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(77, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(82, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(83, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(84, 10);
    cc.tiles["CIB_R49C48:CIB_DCU3"].add_unknown(85, 10);
    cc.tiles["CIB_R49C49:CIB_DCU2"].add_unknown(20, 10);
    cc.tiles["CIB_R49C49:CIB_DCU2"].add_unknown(22, 10);
    cc.tiles["CIB_R49C49:CIB_DCU2"].add_unknown(29, 10);
    cc.tiles["CIB_R49C49:CIB_DCU2"].add_unknown(31, 10);
    cc.tiles["CIB_R49C49:CIB_DCU2"].add_unknown(74, 10);
    cc.tiles["CIB_R49C49:CIB_DCU2"].add_unknown(76, 10);
    cc.tiles["CIB_R49C49:CIB_DCU2"].add_unknown(83, 10);
    cc.tiles["CIB_R49C49:CIB_DCU2"].add_unknown(85, 10);
    cc.tiles["CIB_R49C50:CIB_DCUG"].add_unknown(20, 10);
    cc.tiles["CIB_R49C50:CIB_DCUG"].add_unknown(22, 10);
    cc.tiles["CIB_R49C50:CIB_DCUG"].add_unknown(29, 10);
    cc.tiles["CIB_R49C50:CIB_DCUG"].add_unknown(31, 10);
    cc.tiles["CIB_R49C50:CIB_DCUG"].add_unknown(74, 10);
    cc.tiles["CIB_R49C50:CIB_DCUG"].add_unknown(76, 10);
    cc.tiles["CIB_R49C50:CIB_DCUG"].add_unknown(83, 10);
    cc.tiles["CIB_R49C50:CIB_DCUG"].add_unknown(85, 10);
    cc.tiles["CIB_R49C51:CIB_DCUH"].add_unknown(20, 10);
    cc.tiles["CIB_R49C51:CIB_DCUH"].add_unknown(22, 10);
    cc.tiles["CIB_R49C51:CIB_DCUH"].add_unknown(29, 10);
    cc.tiles["CIB_R49C51:CIB_DCUH"].add_unknown(31, 10);
    cc.tiles["CIB_R49C51:CIB_DCUH"].add_unknown(74, 10);
    cc.tiles["CIB_R49C51:CIB_DCUH"].add_unknown(76, 10);
    cc.tiles["CIB_R49C51:CIB_DCUH"].add_unknown(83, 10);
    cc.tiles["CIB_R49C51:CIB_DCUH"].add_unknown(85, 10);
    cc.tiles["CIB_R49C52:CIB_DCUI"].add_unknown(20, 10);
    cc.tiles["CIB_R49C52:CIB_DCUI"].add_unknown(22, 10);
    cc.tiles["CIB_R49C52:CIB_DCUI"].add_unknown(29, 10);
    cc.tiles["CIB_R49C52:CIB_DCUI"].add_unknown(31, 10);
    cc.tiles["CIB_R49C52:CIB_DCUI"].add_unknown(74, 10);
    cc.tiles["CIB_R49C52:CIB_DCUI"].add_unknown(76, 10);
    cc.tiles["CIB_R49C52:CIB_DCUI"].add_unknown(83, 10);
    cc.tiles["CIB_R49C52:CIB_DCUI"].add_unknown(85, 10);
    cc.tiles["CIB_R49C53:CIB_DCU1"].add_unknown(20, 10);
    cc.tiles["CIB_R49C53:CIB_DCU1"].add_unknown(22, 10);
    cc.tiles["CIB_R49C53:CIB_DCU1"].add_unknown(29, 10);
    cc.tiles["CIB_R49C53:CIB_DCU1"].add_unknown(31, 10);
    cc.tiles["CIB_R49C53:CIB_DCU1"].add_unknown(74, 10);
    cc.tiles["CIB_R49C69:CIB_PLL3"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R49C69:CIB_PLL3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C6:CIB_EFB0"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C6:CIB_EFB0"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R49C6:CIB_EFB0"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JA4MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JA6MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JB4MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JB6MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JC3MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JC5MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JD3MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R49C7:CIB_EFB1"].add_enum("CIB.JD5MUX", "0");
    cc.tiles["MIB_R13C31:CMUX_UL_0"].add_arc("G_DCS0CLK0", "G_VPFN0000");
    cc.tiles["MIB_R13C32:CMUX_UR_0"].add_arc("G_DCS0CLK1", "G_VPFN0000");
    cc.tiles["MIB_R13C3:DSP_SPINE_UL1"].add_unknown(2, 0);
    cc.tiles["MIB_R13C3:DSP_SPINE_UL1"].add_unknown(3, 0);
    cc.tiles["MIB_R13C3:DSP_SPINE_UL1"].add_unknown(5, 0);
    cc.tiles["MIB_R13C3:DSP_SPINE_UL1"].add_unknown(11, 0);
    cc.tiles["MIB_R13C3:DSP_SPINE_UL1"].add_unknown(13, 0);
    cc.tiles["MIB_R37C31:CMUX_LL_0"].add_arc("G_DCS1CLK0", "G_VPFN0000");
    cc.tiles["MIB_R37C32:CMUX_LR_0"].add_arc("G_DCS1CLK1", "G_VPFN0000");
    cc.tiles["MIB_R50C4:EFB0_PICB0"].add_unknown(54, 1);
    cc.tiles["MIB_R50C4:EFB0_PICB0"].add_unknown(56, 1);
    cc.tiles["MIB_R50C4:EFB0_PICB0"].add_unknown(82, 1);
    cc.tiles["MIB_R50C4:EFB0_PICB0"].add_unknown(94, 1);
}

void config_empty_lfe5um5g_45f(ChipConfig &cc)
{
    cc.chip_name = "LFE5UM5G-45F";
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(2, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(3, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(5, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(11, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(13, 0);
    cc.tiles["CIB_R5C1:CIB_PLL1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R5C1:CIB_PLL1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R5C89:CIB_PLL1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R5C89:CIB_PLL1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C3:CIB_PLL3"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R70C3:CIB_PLL3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(20, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(21, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(22, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(23, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(28, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(29, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(30, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(31, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(74, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(75, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(76, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(77, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(82, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(83, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(84, 10);
    cc.tiles["CIB_R70C42:CIB_DCU0"].add_unknown(85, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(20, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(21, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(22, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(23, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(28, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(29, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(30, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(31, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(74, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(75, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(76, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(77, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(82, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(83, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(84, 10);
    cc.tiles["CIB_R70C43:CIB_DCUA"].add_unknown(85, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(20, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(21, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(22, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(23, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(28, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(29, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(30, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(31, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(74, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(75, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(76, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(77, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(82, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(83, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(84, 10);
    cc.tiles["CIB_R70C44:CIB_DCUB"].add_unknown(85, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(20, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(21, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(22, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(23, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(28, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(29, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(30, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(31, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(74, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(75, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(76, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(77, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(82, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(83, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(84, 10);
    cc.tiles["CIB_R70C45:CIB_DCUC"].add_unknown(85, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(20, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(21, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(22, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(23, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(28, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(29, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(31, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(74, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(75, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(76, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(77, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(82, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(83, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(84, 10);
    cc.tiles["CIB_R70C46:CIB_DCUD"].add_unknown(85, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(20, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(21, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(22, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(23, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(28, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(29, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(30, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(31, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(74, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(75, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(76, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(77, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(82, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(83, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(84, 10);
    cc.tiles["CIB_R70C47:CIB_DCUF"].add_unknown(85, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(20, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(22, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(23, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(29, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(31, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(74, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(75, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(76, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(77, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(82, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(83, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(84, 10);
    cc.tiles["CIB_R70C48:CIB_DCU3"].add_unknown(85, 10);
    cc.tiles["CIB_R70C49:CIB_DCU2"].add_unknown(20, 10);
    cc.tiles["CIB_R70C49:CIB_DCU2"].add_unknown(22, 10);
    cc.tiles["CIB_R70C49:CIB_DCU2"].add_unknown(29, 10);
    cc.tiles["CIB_R70C49:CIB_DCU2"].add_unknown(31, 10);
    cc.tiles["CIB_R70C49:CIB_DCU2"].add_unknown(74, 10);
    cc.tiles["CIB_R70C49:CIB_DCU2"].add_unknown(76, 10);
    cc.tiles["CIB_R70C49:CIB_DCU2"].add_unknown(83, 10);
    cc.tiles["CIB_R70C49:CIB_DCU2"].add_unknown(85, 10);
    cc.tiles["CIB_R70C50:CIB_DCUG"].add_unknown(20, 10);
    cc.tiles["CIB_R70C50:CIB_DCUG"].add_unknown(22, 10);
    cc.tiles["CIB_R70C50:CIB_DCUG"].add_unknown(29, 10);
    cc.tiles["CIB_R70C50:CIB_DCUG"].add_unknown(31, 10);
    cc.tiles["CIB_R70C50:CIB_DCUG"].add_unknown(74, 10);
    cc.tiles["CIB_R70C50:CIB_DCUG"].add_unknown(76, 10);
    cc.tiles["CIB_R70C50:CIB_DCUG"].add_unknown(83, 10);
    cc.tiles["CIB_R70C50:CIB_DCUG"].add_unknown(85, 10);
    cc.tiles["CIB_R70C51:CIB_DCUH"].add_unknown(20, 10);
    cc.tiles["CIB_R70C51:CIB_DCUH"].add_unknown(22, 10);
    cc.tiles["CIB_R70C51:CIB_DCUH"].add_unknown(29, 10);
    cc.tiles["CIB_R70C51:CIB_DCUH"].add_unknown(31, 10);
    cc.tiles["CIB_R70C51:CIB_DCUH"].add_unknown(74, 10);
    cc.tiles["CIB_R70C51:CIB_DCUH"].add_unknown(76, 10);
    cc.tiles["CIB_R70C51:CIB_DCUH"].add_unknown(83, 10);
    cc.tiles["CIB_R70C51:CIB_DCUH"].add_unknown(85, 10);
    cc.tiles["CIB_R70C52:CIB_DCUI"].add_unknown(20, 10);
    cc.tiles["CIB_R70C52:CIB_DCUI"].add_unknown(22, 10);
    cc.tiles["CIB_R70C52:CIB_DCUI"].add_unknown(29, 10);
    cc.tiles["CIB_R70C52:CIB_DCUI"].add_unknown(31, 10);
    cc.tiles["CIB_R70C52:CIB_DCUI"].add_unknown(74, 10);
    cc.tiles["CIB_R70C52:CIB_DCUI"].add_unknown(76, 10);
    cc.tiles["CIB_R70C52:CIB_DCUI"].add_unknown(83, 10);
    cc.tiles["CIB_R70C52:CIB_DCUI"].add_unknown(85, 10);
    cc.tiles["CIB_R70C53:CIB_DCU1"].add_unknown(20, 10);
    cc.tiles["CIB_R70C53:CIB_DCU1"].add_unknown(22, 10);
    cc.tiles["CIB_R70C53:CIB_DCU1"].add_unknown(29, 10);
    cc.tiles["CIB_R70C53:CIB_DCU1"].add_unknown(31, 10);
    cc.tiles["CIB_R70C53:CIB_DCU1"].add_unknown(74, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(20, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(21, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(22, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(23, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(28, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(29, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(30, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(31, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(74, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(75, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(76, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(77, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(82, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(83, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(84, 10);
    cc.tiles["CIB_R70C69:CIB_DCU0"].add_unknown(85, 10);
    cc.tiles["CIB_R70C6:CIB_EFB0"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C6:CIB_EFB0"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R70C6:CIB_EFB0"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(20, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(21, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(22, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(23, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(28, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(29, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(30, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(31, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(74, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(75, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(76, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(77, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(82, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(83, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(84, 10);
    cc.tiles["CIB_R70C70:CIB_DCUA"].add_unknown(85, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(20, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(21, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(22, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(23, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(28, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(29, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(30, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(31, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(74, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(75, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(76, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(77, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(82, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(83, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(84, 10);
    cc.tiles["CIB_R70C71:CIB_DCUB"].add_unknown(85, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(20, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(21, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(22, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(23, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(28, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(29, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(30, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(31, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(74, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(75, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(76, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(77, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(82, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(83, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(84, 10);
    cc.tiles["CIB_R70C72:CIB_DCUC"].add_unknown(85, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(20, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(21, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(22, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(23, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(28, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(29, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(31, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(74, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(75, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(76, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(77, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(82, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(83, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(84, 10);
    cc.tiles["CIB_R70C73:CIB_DCUD"].add_unknown(85, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(20, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(21, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(22, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(23, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(28, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(29, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(30, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(31, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(74, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(75, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(76, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(77, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(82, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(83, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(84, 10);
    cc.tiles["CIB_R70C74:CIB_DCUF"].add_unknown(85, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(20, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(22, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(23, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(29, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(31, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(74, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(75, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(76, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(77, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(82, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(83, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(84, 10);
    cc.tiles["CIB_R70C75:CIB_DCU3"].add_unknown(85, 10);
    cc.tiles["CIB_R70C76:CIB_DCU2"].add_unknown(20, 10);
    cc.tiles["CIB_R70C76:CIB_DCU2"].add_unknown(22, 10);
    cc.tiles["CIB_R70C76:CIB_DCU2"].add_unknown(29, 10);
    cc.tiles["CIB_R70C76:CIB_DCU2"].add_unknown(31, 10);
    cc.tiles["CIB_R70C76:CIB_DCU2"].add_unknown(74, 10);
    cc.tiles["CIB_R70C76:CIB_DCU2"].add_unknown(76, 10);
    cc.tiles["CIB_R70C76:CIB_DCU2"].add_unknown(83, 10);
    cc.tiles["CIB_R70C76:CIB_DCU2"].add_unknown(85, 10);
    cc.tiles["CIB_R70C77:CIB_DCUG"].add_unknown(20, 10);
    cc.tiles["CIB_R70C77:CIB_DCUG"].add_unknown(22, 10);
    cc.tiles["CIB_R70C77:CIB_DCUG"].add_unknown(29, 10);
    cc.tiles["CIB_R70C77:CIB_DCUG"].add_unknown(31, 10);
    cc.tiles["CIB_R70C77:CIB_DCUG"].add_unknown(74, 10);
    cc.tiles["CIB_R70C77:CIB_DCUG"].add_unknown(76, 10);
    cc.tiles["CIB_R70C77:CIB_DCUG"].add_unknown(83, 10);
    cc.tiles["CIB_R70C77:CIB_DCUG"].add_unknown(85, 10);
    cc.tiles["CIB_R70C78:CIB_DCUH"].add_unknown(20, 10);
    cc.tiles["CIB_R70C78:CIB_DCUH"].add_unknown(22, 10);
    cc.tiles["CIB_R70C78:CIB_DCUH"].add_unknown(29, 10);
    cc.tiles["CIB_R70C78:CIB_DCUH"].add_unknown(31, 10);
    cc.tiles["CIB_R70C78:CIB_DCUH"].add_unknown(74, 10);
    cc.tiles["CIB_R70C78:CIB_DCUH"].add_unknown(76, 10);
    cc.tiles["CIB_R70C78:CIB_DCUH"].add_unknown(83, 10);
    cc.tiles["CIB_R70C78:CIB_DCUH"].add_unknown(85, 10);
    cc.tiles["CIB_R70C79:CIB_DCUI"].add_unknown(20, 10);
    cc.tiles["CIB_R70C79:CIB_DCUI"].add_unknown(22, 10);
    cc.tiles["CIB_R70C79:CIB_DCUI"].add_unknown(29, 10);
    cc.tiles["CIB_R70C79:CIB_DCUI"].add_unknown(31, 10);
    cc.tiles["CIB_R70C79:CIB_DCUI"].add_unknown(74, 10);
    cc.tiles["CIB_R70C79:CIB_DCUI"].add_unknown(76, 10);
    cc.tiles["CIB_R70C79:CIB_DCUI"].add_unknown(83, 10);
    cc.tiles["CIB_R70C79:CIB_DCUI"].add_unknown(85, 10);
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JA4MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JA6MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JB4MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JB6MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JC3MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JC5MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JD3MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R70C7:CIB_EFB1"].add_enum("CIB.JD5MUX", "0");
    cc.tiles["CIB_R70C80:CIB_DCU1"].add_unknown(20, 10);
    cc.tiles["CIB_R70C80:CIB_DCU1"].add_unknown(22, 10);
    cc.tiles["CIB_R70C80:CIB_DCU1"].add_unknown(29, 10);
    cc.tiles["CIB_R70C80:CIB_DCU1"].add_unknown(31, 10);
    cc.tiles["CIB_R70C80:CIB_DCU1"].add_unknown(74, 10);
    cc.tiles["CIB_R70C87:CIB_PLL3"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R70C87:CIB_PLL3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["MIB_R10C40:CMUX_UL_0"].add_arc("G_DCS0CLK0", "G_VPFN0000");
    cc.tiles["MIB_R10C41:CMUX_UR_0"].add_arc("G_DCS0CLK1", "G_VPFN0000");
    cc.tiles["MIB_R58C40:CMUX_LL_0"].add_arc("G_DCS1CLK0", "G_VPFN0000");
    cc.tiles["MIB_R58C41:CMUX_LR_0"].add_arc("G_DCS1CLK1", "G_VPFN0000");
    cc.tiles["MIB_R71C4:EFB0_PICB0"].add_unknown(54, 1);
    cc.tiles["MIB_R71C4:EFB0_PICB0"].add_unknown(56, 1);
    cc.tiles["MIB_R71C4:EFB0_PICB0"].add_unknown(82, 1);
    cc.tiles["MIB_R71C4:EFB0_PICB0"].add_unknown(94, 1);
}

void config_empty_lfe5um5g_85f(ChipConfig &cc)
{
    cc.chip_name = "LFE5UM5G-85F";
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(2, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(3, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(5, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(11, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(13, 0);
    cc.tiles["CIB_R5C125:CIB_PLL1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R5C125:CIB_PLL1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R5C1:CIB_PLL1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R5C1:CIB_PLL1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C123:CIB_PLL3"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R94C123:CIB_PLL3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C3:CIB_PLL3"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R94C3:CIB_PLL3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(20, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(21, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(22, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(23, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(28, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(29, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(30, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(31, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(74, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(75, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(76, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(77, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(82, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(83, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(84, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(85, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(20, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(21, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(22, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(23, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(28, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(29, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(30, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(31, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(74, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(75, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(76, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(77, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(82, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(83, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(84, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(85, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(20, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(21, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(22, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(23, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(28, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(29, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(30, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(31, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(74, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(75, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(76, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(77, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(82, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(83, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(84, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(85, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(20, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(21, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(22, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(23, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(28, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(29, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(30, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(31, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(74, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(75, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(76, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(77, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(82, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(83, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(84, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(85, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(20, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(21, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(22, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(23, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(28, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(29, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(31, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(74, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(75, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(76, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(77, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(82, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(83, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(84, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(85, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(20, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(21, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(22, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(23, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(28, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(29, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(30, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(31, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(74, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(75, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(76, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(77, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(82, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(83, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(84, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(85, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(20, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(22, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(23, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(29, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(31, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(74, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(75, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(76, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(77, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(82, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(83, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(84, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(85, 10);
    cc.tiles["CIB_R94C53:CIB_DCU2"].add_unknown(20, 10);
    cc.tiles["CIB_R94C53:CIB_DCU2"].add_unknown(22, 10);
    cc.tiles["CIB_R94C53:CIB_DCU2"].add_unknown(29, 10);
    cc.tiles["CIB_R94C53:CIB_DCU2"].add_unknown(31, 10);
    cc.tiles["CIB_R94C53:CIB_DCU2"].add_unknown(74, 10);
    cc.tiles["CIB_R94C53:CIB_DCU2"].add_unknown(76, 10);
    cc.tiles["CIB_R94C53:CIB_DCU2"].add_unknown(83, 10);
    cc.tiles["CIB_R94C53:CIB_DCU2"].add_unknown(85, 10);
    cc.tiles["CIB_R94C54:CIB_DCUG"].add_unknown(20, 10);
    cc.tiles["CIB_R94C54:CIB_DCUG"].add_unknown(22, 10);
    cc.tiles["CIB_R94C54:CIB_DCUG"].add_unknown(29, 10);
    cc.tiles["CIB_R94C54:CIB_DCUG"].add_unknown(31, 10);
    cc.tiles["CIB_R94C54:CIB_DCUG"].add_unknown(74, 10);
    cc.tiles["CIB_R94C54:CIB_DCUG"].add_unknown(76, 10);
    cc.tiles["CIB_R94C54:CIB_DCUG"].add_unknown(83, 10);
    cc.tiles["CIB_R94C54:CIB_DCUG"].add_unknown(85, 10);
    cc.tiles["CIB_R94C55:CIB_DCUH"].add_unknown(20, 10);
    cc.tiles["CIB_R94C55:CIB_DCUH"].add_unknown(22, 10);
    cc.tiles["CIB_R94C55:CIB_DCUH"].add_unknown(29, 10);
    cc.tiles["CIB_R94C55:CIB_DCUH"].add_unknown(31, 10);
    cc.tiles["CIB_R94C55:CIB_DCUH"].add_unknown(74, 10);
    cc.tiles["CIB_R94C55:CIB_DCUH"].add_unknown(76, 10);
    cc.tiles["CIB_R94C55:CIB_DCUH"].add_unknown(83, 10);
    cc.tiles["CIB_R94C55:CIB_DCUH"].add_unknown(85, 10);
    cc.tiles["CIB_R94C56:CIB_DCUI"].add_unknown(20, 10);
    cc.tiles["CIB_R94C56:CIB_DCUI"].add_unknown(22, 10);
    cc.tiles["CIB_R94C56:CIB_DCUI"].add_unknown(29, 10);
    cc.tiles["CIB_R94C56:CIB_DCUI"].add_unknown(31, 10);
    cc.tiles["CIB_R94C56:CIB_DCUI"].add_unknown(74, 10);
    cc.tiles["CIB_R94C56:CIB_DCUI"].add_unknown(76, 10);
    cc.tiles["CIB_R94C56:CIB_DCUI"].add_unknown(83, 10);
    cc.tiles["CIB_R94C56:CIB_DCUI"].add_unknown(85, 10);
    cc.tiles["CIB_R94C57:CIB_DCU1"].add_unknown(20, 10);
    cc.tiles["CIB_R94C57:CIB_DCU1"].add_unknown(22, 10);
    cc.tiles["CIB_R94C57:CIB_DCU1"].add_unknown(29, 10);
    cc.tiles["CIB_R94C57:CIB_DCU1"].add_unknown(31, 10);
    cc.tiles["CIB_R94C57:CIB_DCU1"].add_unknown(74, 10);
    cc.tiles["CIB_R94C6:CIB_EFB0"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C6:CIB_EFB0"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R94C6:CIB_EFB0"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(20, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(21, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(22, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(23, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(28, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(29, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(30, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(31, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(74, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(75, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(76, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(77, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(82, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(83, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(84, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(85, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(20, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(21, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(22, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(23, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(28, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(29, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(30, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(31, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(74, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(75, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(76, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(77, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(82, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(83, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(84, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(85, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(20, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(21, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(22, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(23, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(28, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(29, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(30, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(31, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(74, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(75, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(76, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(77, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(82, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(83, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(84, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(85, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(20, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(21, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(22, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(23, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(28, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(29, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(30, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(31, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(74, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(75, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(76, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(77, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(82, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(83, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(84, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(85, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(20, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(21, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(22, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(23, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(28, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(29, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(31, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(74, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(75, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(76, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(77, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(82, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(83, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(84, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(85, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(20, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(21, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(22, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(23, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(28, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(29, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(30, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(31, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(74, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(75, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(76, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(77, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(82, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(83, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(84, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(85, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(20, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(22, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(23, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(29, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(31, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(74, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(75, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(76, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(77, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(82, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(83, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(84, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(85, 10);
    cc.tiles["CIB_R94C78:CIB_DCU2"].add_unknown(20, 10);
    cc.tiles["CIB_R94C78:CIB_DCU2"].add_unknown(22, 10);
    cc.tiles["CIB_R94C78:CIB_DCU2"].add_unknown(29, 10);
    cc.tiles["CIB_R94C78:CIB_DCU2"].add_unknown(31, 10);
    cc.tiles["CIB_R94C78:CIB_DCU2"].add_unknown(74, 10);
    cc.tiles["CIB_R94C78:CIB_DCU2"].add_unknown(76, 10);
    cc.tiles["CIB_R94C78:CIB_DCU2"].add_unknown(83, 10);
    cc.tiles["CIB_R94C78:CIB_DCU2"].add_unknown(85, 10);
    cc.tiles["CIB_R94C79:CIB_DCUG"].add_unknown(20, 10);
    cc.tiles["CIB_R94C79:CIB_DCUG"].add_unknown(22, 10);
    cc.tiles["CIB_R94C79:CIB_DCUG"].add_unknown(29, 10);
    cc.tiles["CIB_R94C79:CIB_DCUG"].add_unknown(31, 10);
    cc.tiles["CIB_R94C79:CIB_DCUG"].add_unknown(74, 10);
    cc.tiles["CIB_R94C79:CIB_DCUG"].add_unknown(76, 10);
    cc.tiles["CIB_R94C79:CIB_DCUG"].add_unknown(83, 10);
    cc.tiles["CIB_R94C79:CIB_DCUG"].add_unknown(85, 10);
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JA4MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JA6MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JB4MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JB6MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JC3MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JC5MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JD3MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JD5MUX", "0");
    cc.tiles["CIB_R94C80:CIB_DCUH"].add_unknown(20, 10);
    cc.tiles["CIB_R94C80:CIB_DCUH"].add_unknown(22, 10);
    cc.tiles["CIB_R94C80:CIB_DCUH"].add_unknown(29, 10);
    cc.tiles["CIB_R94C80:CIB_DCUH"].add_unknown(31, 10);
    cc.tiles["CIB_R94C80:CIB_DCUH"].add_unknown(74, 10);
    cc.tiles["CIB_R94C80:CIB_DCUH"].add_unknown(76, 10);
    cc.tiles["CIB_R94C80:CIB_DCUH"].add_unknown(83, 10);
    cc.tiles["CIB_R94C80:CIB_DCUH"].add_unknown(85, 10);
    cc.tiles["CIB_R94C81:CIB_DCUI"].add_unknown(20, 10);
    cc.tiles["CIB_R94C81:CIB_DCUI"].add_unknown(22, 10);
    cc.tiles["CIB_R94C81:CIB_DCUI"].add_unknown(29, 10);
    cc.tiles["CIB_R94C81:CIB_DCUI"].add_unknown(31, 10);
    cc.tiles["CIB_R94C81:CIB_DCUI"].add_unknown(74, 10);
    cc.tiles["CIB_R94C81:CIB_DCUI"].add_unknown(76, 10);
    cc.tiles["CIB_R94C81:CIB_DCUI"].add_unknown(83, 10);
    cc.tiles["CIB_R94C81:CIB_DCUI"].add_unknown(85, 10);
    cc.tiles["CIB_R94C82:CIB_DCU1"].add_unknown(20, 10);
    cc.tiles["CIB_R94C82:CIB_DCU1"].add_unknown(22, 10);
    cc.tiles["CIB_R94C82:CIB_DCU1"].add_unknown(29, 10);
    cc.tiles["CIB_R94C82:CIB_DCU1"].add_unknown(31, 10);
    cc.tiles["CIB_R94C82:CIB_DCU1"].add_unknown(74, 10);
    cc.tiles["MIB_R22C67:CMUX_UL_0"].add_arc("G_DCS0CLK0", "G_VPFN0000");
    cc.tiles["MIB_R22C68:CMUX_UR_0"].add_arc("G_DCS0CLK1", "G_VPFN0000");
    cc.tiles["MIB_R70C67:CMUX_LL_0"].add_arc("G_DCS1CLK0", "G_VPFN0000");
    cc.tiles["MIB_R70C68:CMUX_LR_0"].add_arc("G_DCS1CLK1", "G_VPFN0000");
    cc.tiles["MIB_R95C101:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C102:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C103:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C104:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C105:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C106:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C107:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C108:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C110:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C111:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C112:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C113:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C114:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C115:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C116:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C117:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C119:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C120:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C121:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C122:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C4:EFB0_PICB0"].add_unknown(54, 1);
    cc.tiles["MIB_R95C4:EFB0_PICB0"].add_unknown(56, 1);
    cc.tiles["MIB_R95C4:EFB0_PICB0"].add_unknown(82, 1);
    cc.tiles["MIB_R95C4:EFB0_PICB0"].add_unknown(94, 1);
    cc.tiles["MIB_R95C96:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C97:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C98:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C99:PICB1"].add_unknown(0, 1);
}

void config_empty_lfe5um_85f(ChipConfig &cc)
{
    cc.chip_name = "LFE5UM-85F";
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(2, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(3, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(5, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(11, 0);
    cc.tiles["CIB_R10C3:PVT_COUNT2"].add_unknown(13, 0);
    cc.tiles["CIB_R5C125:CIB_PLL1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R5C125:CIB_PLL1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R5C1:CIB_PLL1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R5C1:CIB_PLL1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C123:CIB_PLL3"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R94C123:CIB_PLL3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C3:CIB_PLL3"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R94C3:CIB_PLL3"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(20, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(21, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(22, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(23, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(28, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(29, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(30, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(31, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(74, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(75, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(76, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(77, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(82, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(83, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(84, 10);
    cc.tiles["CIB_R94C46:CIB_DCU0"].add_unknown(85, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(20, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(21, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(22, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(23, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(28, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(29, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(30, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(31, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(74, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(75, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(76, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(77, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(82, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(83, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(84, 10);
    cc.tiles["CIB_R94C47:CIB_DCUA"].add_unknown(85, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(20, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(21, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(22, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(23, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(28, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(29, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(30, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(31, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(74, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(75, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(76, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(77, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(82, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(83, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(84, 10);
    cc.tiles["CIB_R94C48:CIB_DCUB"].add_unknown(85, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(20, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(21, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(22, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(23, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(28, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(29, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(30, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(31, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(74, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(75, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(76, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(77, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(82, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(83, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(84, 10);
    cc.tiles["CIB_R94C49:CIB_DCUC"].add_unknown(85, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(20, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(21, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(22, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(23, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(28, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(29, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(31, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(74, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(75, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(76, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(77, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(82, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(83, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(84, 10);
    cc.tiles["CIB_R94C50:CIB_DCUD"].add_unknown(85, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(20, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(21, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(22, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(23, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(28, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(29, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(30, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(31, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(74, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(75, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(76, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(77, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(82, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(83, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(84, 10);
    cc.tiles["CIB_R94C51:CIB_DCUF"].add_unknown(85, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(20, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(22, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(23, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(29, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(31, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(74, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(75, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(76, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(77, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(82, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(83, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(84, 10);
    cc.tiles["CIB_R94C52:CIB_DCU3"].add_unknown(85, 10);
    cc.tiles["CIB_R94C53:CIB_DCU2"].add_unknown(20, 10);
    cc.tiles["CIB_R94C53:CIB_DCU2"].add_unknown(22, 10);
    cc.tiles["CIB_R94C53:CIB_DCU2"].add_unknown(29, 10);
    cc.tiles["CIB_R94C53:CIB_DCU2"].add_unknown(31, 10);
    cc.tiles["CIB_R94C53:CIB_DCU2"].add_unknown(74, 10);
    cc.tiles["CIB_R94C53:CIB_DCU2"].add_unknown(76, 10);
    cc.tiles["CIB_R94C53:CIB_DCU2"].add_unknown(83, 10);
    cc.tiles["CIB_R94C53:CIB_DCU2"].add_unknown(85, 10);
    cc.tiles["CIB_R94C54:CIB_DCUG"].add_unknown(20, 10);
    cc.tiles["CIB_R94C54:CIB_DCUG"].add_unknown(22, 10);
    cc.tiles["CIB_R94C54:CIB_DCUG"].add_unknown(29, 10);
    cc.tiles["CIB_R94C54:CIB_DCUG"].add_unknown(31, 10);
    cc.tiles["CIB_R94C54:CIB_DCUG"].add_unknown(74, 10);
    cc.tiles["CIB_R94C54:CIB_DCUG"].add_unknown(76, 10);
    cc.tiles["CIB_R94C54:CIB_DCUG"].add_unknown(83, 10);
    cc.tiles["CIB_R94C54:CIB_DCUG"].add_unknown(85, 10);
    cc.tiles["CIB_R94C55:CIB_DCUH"].add_unknown(20, 10);
    cc.tiles["CIB_R94C55:CIB_DCUH"].add_unknown(22, 10);
    cc.tiles["CIB_R94C55:CIB_DCUH"].add_unknown(29, 10);
    cc.tiles["CIB_R94C55:CIB_DCUH"].add_unknown(31, 10);
    cc.tiles["CIB_R94C55:CIB_DCUH"].add_unknown(74, 10);
    cc.tiles["CIB_R94C55:CIB_DCUH"].add_unknown(76, 10);
    cc.tiles["CIB_R94C55:CIB_DCUH"].add_unknown(83, 10);
    cc.tiles["CIB_R94C55:CIB_DCUH"].add_unknown(85, 10);
    cc.tiles["CIB_R94C56:CIB_DCUI"].add_unknown(20, 10);
    cc.tiles["CIB_R94C56:CIB_DCUI"].add_unknown(22, 10);
    cc.tiles["CIB_R94C56:CIB_DCUI"].add_unknown(29, 10);
    cc.tiles["CIB_R94C56:CIB_DCUI"].add_unknown(31, 10);
    cc.tiles["CIB_R94C56:CIB_DCUI"].add_unknown(74, 10);
    cc.tiles["CIB_R94C56:CIB_DCUI"].add_unknown(76, 10);
    cc.tiles["CIB_R94C56:CIB_DCUI"].add_unknown(83, 10);
    cc.tiles["CIB_R94C56:CIB_DCUI"].add_unknown(85, 10);
    cc.tiles["CIB_R94C57:CIB_DCU1"].add_unknown(20, 10);
    cc.tiles["CIB_R94C57:CIB_DCU1"].add_unknown(22, 10);
    cc.tiles["CIB_R94C57:CIB_DCU1"].add_unknown(29, 10);
    cc.tiles["CIB_R94C57:CIB_DCU1"].add_unknown(31, 10);
    cc.tiles["CIB_R94C57:CIB_DCU1"].add_unknown(74, 10);
    cc.tiles["CIB_R94C6:CIB_EFB0"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C6:CIB_EFB0"].add_enum("CIB.JC6MUX", "0");
    cc.tiles["CIB_R94C6:CIB_EFB0"].add_enum("CIB.JD6MUX", "0");
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(20, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(21, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(22, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(23, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(28, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(29, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(30, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(31, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(74, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(75, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(76, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(77, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(82, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(83, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(84, 10);
    cc.tiles["CIB_R94C71:CIB_DCU0"].add_unknown(85, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(20, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(21, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(22, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(23, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(28, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(29, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(30, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(31, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(74, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(75, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(76, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(77, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(82, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(83, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(84, 10);
    cc.tiles["CIB_R94C72:CIB_DCUA"].add_unknown(85, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(20, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(21, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(22, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(23, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(28, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(29, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(30, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(31, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(74, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(75, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(76, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(77, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(82, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(83, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(84, 10);
    cc.tiles["CIB_R94C73:CIB_DCUB"].add_unknown(85, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(20, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(21, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(22, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(23, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(28, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(29, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(30, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(31, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(74, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(75, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(76, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(77, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(82, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(83, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(84, 10);
    cc.tiles["CIB_R94C74:CIB_DCUC"].add_unknown(85, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(20, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(21, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(22, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(23, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(28, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(29, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(31, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(74, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(75, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(76, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(77, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(82, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(83, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(84, 10);
    cc.tiles["CIB_R94C75:CIB_DCUD"].add_unknown(85, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(20, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(21, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(22, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(23, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(28, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(29, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(30, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(31, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(74, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(75, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(76, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(77, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(82, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(83, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(84, 10);
    cc.tiles["CIB_R94C76:CIB_DCUF"].add_unknown(85, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(20, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(22, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(23, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(29, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(31, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(74, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(75, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(76, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(77, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(82, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(83, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(84, 10);
    cc.tiles["CIB_R94C77:CIB_DCU3"].add_unknown(85, 10);
    cc.tiles["CIB_R94C78:CIB_DCU2"].add_unknown(20, 10);
    cc.tiles["CIB_R94C78:CIB_DCU2"].add_unknown(22, 10);
    cc.tiles["CIB_R94C78:CIB_DCU2"].add_unknown(29, 10);
    cc.tiles["CIB_R94C78:CIB_DCU2"].add_unknown(31, 10);
    cc.tiles["CIB_R94C78:CIB_DCU2"].add_unknown(74, 10);
    cc.tiles["CIB_R94C78:CIB_DCU2"].add_unknown(76, 10);
    cc.tiles["CIB_R94C78:CIB_DCU2"].add_unknown(83, 10);
    cc.tiles["CIB_R94C78:CIB_DCU2"].add_unknown(85, 10);
    cc.tiles["CIB_R94C79:CIB_DCUG"].add_unknown(20, 10);
    cc.tiles["CIB_R94C79:CIB_DCUG"].add_unknown(22, 10);
    cc.tiles["CIB_R94C79:CIB_DCUG"].add_unknown(29, 10);
    cc.tiles["CIB_R94C79:CIB_DCUG"].add_unknown(31, 10);
    cc.tiles["CIB_R94C79:CIB_DCUG"].add_unknown(74, 10);
    cc.tiles["CIB_R94C79:CIB_DCUG"].add_unknown(76, 10);
    cc.tiles["CIB_R94C79:CIB_DCUG"].add_unknown(83, 10);
    cc.tiles["CIB_R94C79:CIB_DCUG"].add_unknown(85, 10);
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JA3MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JA4MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JA5MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JA6MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JB3MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JB4MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JB5MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JB6MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JC3MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JC4MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JC5MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JD3MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JD4MUX", "0");
    cc.tiles["CIB_R94C7:CIB_EFB1"].add_enum("CIB.JD5MUX", "0");
    cc.tiles["CIB_R94C80:CIB_DCUH"].add_unknown(20, 10);
    cc.tiles["CIB_R94C80:CIB_DCUH"].add_unknown(22, 10);
    cc.tiles["CIB_R94C80:CIB_DCUH"].add_unknown(29, 10);
    cc.tiles["CIB_R94C80:CIB_DCUH"].add_unknown(31, 10);
    cc.tiles["CIB_R94C80:CIB_DCUH"].add_unknown(74, 10);
    cc.tiles["CIB_R94C80:CIB_DCUH"].add_unknown(76, 10);
    cc.tiles["CIB_R94C80:CIB_DCUH"].add_unknown(83, 10);
    cc.tiles["CIB_R94C80:CIB_DCUH"].add_unknown(85, 10);
    cc.tiles["CIB_R94C81:CIB_DCUI"].add_unknown(20, 10);
    cc.tiles["CIB_R94C81:CIB_DCUI"].add_unknown(22, 10);
    cc.tiles["CIB_R94C81:CIB_DCUI"].add_unknown(29, 10);
    cc.tiles["CIB_R94C81:CIB_DCUI"].add_unknown(31, 10);
    cc.tiles["CIB_R94C81:CIB_DCUI"].add_unknown(74, 10);
    cc.tiles["CIB_R94C81:CIB_DCUI"].add_unknown(76, 10);
    cc.tiles["CIB_R94C81:CIB_DCUI"].add_unknown(83, 10);
    cc.tiles["CIB_R94C81:CIB_DCUI"].add_unknown(85, 10);
    cc.tiles["CIB_R94C82:CIB_DCU1"].add_unknown(20, 10);
    cc.tiles["CIB_R94C82:CIB_DCU1"].add_unknown(22, 10);
    cc.tiles["CIB_R94C82:CIB_DCU1"].add_unknown(29, 10);
    cc.tiles["CIB_R94C82:CIB_DCU1"].add_unknown(31, 10);
    cc.tiles["CIB_R94C82:CIB_DCU1"].add_unknown(74, 10);
    cc.tiles["MIB_R22C67:CMUX_UL_0"].add_arc("G_DCS0CLK0", "G_VPFN0000");
    cc.tiles["MIB_R22C68:CMUX_UR_0"].add_arc("G_DCS0CLK1", "G_VPFN0000");
    cc.tiles["MIB_R70C67:CMUX_LL_0"].add_arc("G_DCS1CLK0", "G_VPFN0000");
    cc.tiles["MIB_R70C68:CMUX_LR_0"].add_arc("G_DCS1CLK1", "G_VPFN0000");
    cc.tiles["MIB_R95C101:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C102:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C103:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C104:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C105:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C106:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C107:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C108:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C110:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C111:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C112:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C113:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C114:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C115:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C116:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C117:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C119:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C120:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C121:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C122:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C4:EFB0_PICB0"].add_unknown(54, 1);
    cc.tiles["MIB_R95C4:EFB0_PICB0"].add_unknown(56, 1);
    cc.tiles["MIB_R95C4:EFB0_PICB0"].add_unknown(82, 1);
    cc.tiles["MIB_R95C4:EFB0_PICB0"].add_unknown(94, 1);
    cc.tiles["MIB_R95C96:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C97:PICB1"].add_unknown(0, 1);
    cc.tiles["MIB_R95C98:PICB0"].add_unknown(0, 1);
    cc.tiles["MIB_R95C99:PICB1"].add_unknown(0, 1);
}

} // namespace BaseConfigs
NEXTPNR_NAMESPACE_END
